==> haskell-mime-mail-0.5.1-148-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mime-mail
version:              0.5.1
visibility:           public
id:                   mime-mail-0.5.1-5qtCHq9GmWQLJHSyFvZUr5
key:                  mime-mail-0.5.1-5qtCHq9GmWQLJHSyFvZUr5
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>

author:               Michael Snoyman <michael@snoyman.com>
homepage:             http://github.com/snoyberg/mime-mail
synopsis:             Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.

category:             Email
abi:                  f7f4716cba3ff51ce1dd9dacb51b870f
exposed:              True
exposed-modules:      Network.Mail.Mime
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mime-mail-0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mime-mail-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mime-mail
hs-libraries:         HSmime-mail-0.5.1-5qtCHq9GmWQLJHSyFvZUr5
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-HHVXuywFN4mBHj78fCyIyn
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    filepath-1.4.2.2 process-1.6.16.0
    random-1.2.1.2-3dTxaovgjM1Bg7GihufWfn text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html:         /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mime-mail-0.5.1-149-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mime-mail.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mime-mail
version:              0.5.1
visibility:           public
id:                   mime-mail-0.5.1-B9wgfdBs0t98dzMQvbTGnd
key:                  mime-mail-0.5.1-B9wgfdBs0t98dzMQvbTGnd
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>

author:               Michael Snoyman <michael@snoyman.com>
homepage:             http://github.com/snoyberg/mime-mail
synopsis:             Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.

category:             Email
abi:                  2ce30c1f326b350e60a9ca788e6902b6
exposed:              True
exposed-modules:      Network.Mail.Mime
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mime-mail-0.5.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mime-mail-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mime-mail
hs-libraries:         HSmime-mail-0.5.1-B9wgfdBs0t98dzMQvbTGnd
depends:
    base-4.16.4.0 base64-bytestring-1.2.1.0-4uOt2Tmyc0i8lodPqODz42
    blaze-builder-0.4.2.3-IKxRmKhVbHpBC9UJti3YbK bytestring-0.11.4.0
    filepath-1.4.2.2 process-1.6.16.0
    random-1.2.1.2-16EsFile9CO8LN79UJ2fx text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html:         /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
